@@ -2,18 +2,21 @@ SummaryStats <-
 function(x=NULL, by=NULL, data=d, rows=NULL, n_cat=getOption("n_cat"), 
     digits_d=NULL, brief=getOption("brief"), label_max=20, ...)  {
 
+
   # a dot in a parameter name to an underscore
   dots <- list(...)
   if (!is.null(dots)) if (length(dots) > 0) {
-    change <- c("n.cat", "digits.d", "label.max")
     for (i in 1:length(dots)) {
-      if (names(dots)[i] %in% change) {
+      if (names(dots)[i] == "values.cex")  values_size <- dots[[i]]
+      if (grepl(".", names(dots)[i], fixed=TRUE)) {
         nm <- gsub(".", "_", names(dots)[i], fixed=TRUE)
         assign(nm, dots[[i]])
         get(nm)
       }
     }
-  }  # let deprecated mydata work as default
+  }
+
+  # let deprecated mydata work as default
   dfs <- .getdfs() 
   mydata.ok <- FALSE
   if ("mydata" %in% dfs  &&  !("d" %in% dfs)) {
