@@ -13,6 +13,7 @@ function(mylevels, color, fill, shp, trans_pts, col.bg, usr,
 
   wt <- 10
   legend_title  <- abbreviate(by.name, wt)
+  mx.ch <- max(c(nchar(legend_labels), nchar(legend_title) - 3))
 
   ll <- legend(0,0, legend=legend_labels, title=legend_title, cex=.7,
                pt.cex=pt.size, pt.lwd=pt.lwd, plot=FALSE)
@@ -22,7 +23,8 @@ function(mylevels, color, fill, shp, trans_pts, col.bg, usr,
   epsilon <- (size[1] - ll$rect$w) / 2
 
   axis_vert <- usr[4] - usr[3]
-  xleft <- usr[2] + epsilon  # usr[2] user coordinate of right axis
+  xleft <- usr[2] + epsilon - .01 # usr[2] user coordinate of right axis
+  if (mx.ch > 7) xleft <- xleft - .02  # shift legend left a bit   
   lgnd.vhalf <- (ll$rect$h) / 2
   axis_cntr <- axis_vert / 2  + usr[3]
   ytop <- axis_cntr + lgnd.vhalf  # user coordinate of legend top
@@ -44,6 +46,7 @@ function(mylevels, color, fill, shp, trans_pts, col.bg, usr,
     adj <- .RSadj(axis_cex=axis_x_cex); axis_x_cex <- adj$axis_cex
     legend_size <- axis_x_cex
   }
+  legend_size <- 1.1 * legend_size
 
   # fill=length(legend_labels):1  puts the legend labels in the correct
   #   order, but only for inflexible boxes that cannot be resized with pt.cex
