@@ -3,23 +3,27 @@ knitr::opts_chunk$set(fig.width=4, fig.height=3.5)
 
 ## ---------------------------------------------------------------------------------------------------------------------
 library("lessR")
+style()
 
 ## ----read-------------------------------------------------------------------------------------------------------------
 d <- Read("Employee")
 
-## ----sp---------------------------------------------------------------------------------------------------------------
+## ----sp, fig.width=4.5------------------------------------------------------------------------------------------------
 Plot(Years, Salary)
 
-## ----spEnhance--------------------------------------------------------------------------------------------------------
+## ----spEnhance, fig.width=4.5-----------------------------------------------------------------------------------------
 Plot(Years, Salary, enhance=TRUE)
 
-## ----size-------------------------------------------------------------------------------------------------------------
+## ----sploess, fig.width=4.5-------------------------------------------------------------------------------------------
+Plot(Years, Salary, fit="loess", plot_errors=TRUE)
+
+## ----size, fig.width=4.5----------------------------------------------------------------------------------------------
 Plot(Years, Salary, size=Pre)
 
 ## ----by, fig.width=5--------------------------------------------------------------------------------------------------
 Plot(Years, Salary, by=Gender)
 
-## ---- fig.height=4----------------------------------------------------------------------------------------------------
+## ---- , fig.width=4.5, fig.height=4-----------------------------------------------------------------------------------
 Plot(Years, Salary, by1=Gender)
 
 ## ---------------------------------------------------------------------------------------------------------------------
@@ -31,10 +35,10 @@ Plot(Salary)
 ## ---------------------------------------------------------------------------------------------------------------------
 Plot(Dept)
 
-## ---- fig.height=5.5--------------------------------------------------------------------------------------------------
+## ---- fig.height=5.5, fig.width=4.5-----------------------------------------------------------------------------------
 Plot(Salary, row_names)
 
-## ---- fig.height=5.5--------------------------------------------------------------------------------------------------
+## ---- fig.height=5.5, fig.width=4.5-----------------------------------------------------------------------------------
 Plot(Salary, row_names, sort_yx="0", segments_y=FALSE)
 
 ## ---- fig.width=5, fig.height=5.5-------------------------------------------------------------------------------------
@@ -58,6 +62,9 @@ style(sub_theme="black", trans=.55,
       window_fill="gray10", grid_color="gray25")
 Plot(date, Price, by1=Company, n_col=1,  fill="darkred", color="red")
 
+## ---------------------------------------------------------------------------------------------------------------------
+style()
+
 ## ---------------------------------------------------------------------------------------------------------------------
 d <- Read("Employee")
 
